@@ -46,7 +46,7 @@ class CfnByteMatchSet(
         id: builtins.str,
         *,
         name: builtins.str,
-        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]] = None,
+        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::WAF::ByteMatchSet``.
 
@@ -287,7 +287,7 @@ class CfnByteMatchSetProps:
         self,
         *,
         name: builtins.str,
-        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnByteMatchSet.ByteMatchTupleProperty]]]] = None,
+        byte_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnByteMatchSet.ByteMatchTupleProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::WAF::ByteMatchSet``.
 
@@ -353,7 +353,7 @@ class CfnIPSet(
         id: builtins.str,
         *,
         name: builtins.str,
-        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnIPSet.IPSetDescriptorProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::WAF::IPSet``.
 
@@ -493,7 +493,7 @@ class CfnIPSetProps:
         self,
         *,
         name: builtins.str,
-        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnIPSet.IPSetDescriptorProperty]]]] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnIPSet.IPSetDescriptorProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::WAF::IPSet``.
 
@@ -560,7 +560,7 @@ class CfnRule(
         *,
         metric_name: builtins.str,
         name: builtins.str,
-        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]] = None,
+        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnRule.PredicateProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::WAF::Rule``.
 
@@ -732,7 +732,7 @@ class CfnRuleProps:
         *,
         metric_name: builtins.str,
         name: builtins.str,
-        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnRule.PredicateProperty]]]] = None,
+        predicates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnRule.PredicateProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::WAF::Rule``.
 
@@ -810,7 +810,7 @@ class CfnSizeConstraintSet(
         id: builtins.str,
         *,
         name: builtins.str,
-        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.SizeConstraintProperty"]]],
+        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnSizeConstraintSet.SizeConstraintProperty"]]],
     ) -> None:
         '''Create a new ``AWS::WAF::SizeConstraintSet``.
 
@@ -1037,7 +1037,7 @@ class CfnSizeConstraintSetProps:
         self,
         *,
         name: builtins.str,
-        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnSizeConstraintSet.SizeConstraintProperty]]],
+        size_constraints: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnSizeConstraintSet.SizeConstraintProperty]]],
     ) -> None:
         '''Properties for defining a ``AWS::WAF::SizeConstraintSet``.
 
@@ -1103,7 +1103,7 @@ class CfnSqlInjectionMatchSet(
         id: builtins.str,
         *,
         name: builtins.str,
-        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1307,7 +1307,7 @@ class CfnSqlInjectionMatchSetProps:
         self,
         *,
         name: builtins.str,
-        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty]]]] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1375,7 +1375,7 @@ class CfnWebACL(
         default_action: typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable],
         metric_name: builtins.str,
         name: builtins.str,
-        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]] = None,
+        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::WAF::WebACL``.
 
@@ -1612,7 +1612,7 @@ class CfnWebACLProps:
         default_action: typing.Union[CfnWebACL.WafActionProperty, aws_cdk.core.IResolvable],
         metric_name: builtins.str,
         name: builtins.str,
-        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnWebACL.ActivatedRuleProperty]]]] = None,
+        rules: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnWebACL.ActivatedRuleProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::WAF::WebACL``.
 
@@ -1704,7 +1704,7 @@ class CfnXssMatchSet(
         id: builtins.str,
         *,
         name: builtins.str,
-        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"]]],
+        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnXssMatchSet.XssMatchTupleProperty"]]],
     ) -> None:
         '''Create a new ``AWS::WAF::XssMatchSet``.
 
@@ -1903,7 +1903,7 @@ class CfnXssMatchSetProps:
         self,
         *,
         name: builtins.str,
-        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnXssMatchSet.XssMatchTupleProperty]]],
+        xss_match_tuples: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnXssMatchSet.XssMatchTupleProperty]]],
     ) -> None:
         '''Properties for defining a ``AWS::WAF::XssMatchSet``.
 
